# Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: Apache-2.0 OR BSD-3-Clause

import json
import os
import pathlib

from .utils import S3ResourceFetcher


def s3_download(resource_type, resource_name, resource_tags="{}", path=None, first=False):
    """Downloads all resources from S3 that correspond to the passed parameters.

    The caller of this function must handle exceptions generated by invalid parameters
    or other configuration problems.
    """
    resource_tags = json.loads(resource_tags)

    s3_resource_fetcher = S3ResourceFetcher(
        "vmm-reference-test-resources",
        os.path.join(
            pathlib.Path(__file__).parent.absolute(),
            "resource_manifest.json"
        ))

    res = s3_resource_fetcher.download(
        resource_type=resource_type,
        resource_name=resource_name,
        tags=resource_tags,
        download_location=path,
        first=first
    )

    return res
